![](pypolycontain.png "pypolycontain")

## Setup
Our package is now available on pip!
```
pip install pypolycontain
```

## Documentation:
We are working on the [documentation](https://pypolycontain.readthedocs.io/en/latest/). Please regularly check for updates. 

## Publications
* A preprint of the paper on the theoretical background of this package is available [here](https://arxiv.org/pdf/1903.05214.pdf).
* A version of this work is going to be presented in [CDC 2019](https://cdc2019.ieeecss.org/)

## Necessary Dependencies:
* Numpy

### Optional Dependencies (for some features, including optimization-based features)
* [pycdd library](https://pycddlib.readthedocs.io/en/latest/index.html)
* Drake (*please build the python bindings with Gurobi*) [get Drake from here](https://drake.mit.edu/)
* Gurobi 9 or later [Gurobi website](https://gurobi.com) (Free Academic License)


You also have the option to clone the repo and manually add it to your pythonpath. 